@@ -1,6 +1,6 @@
 import base64
 from django.conf import settings
-from keycloak import KeycloakPutError, urls_patterns
+from keycloak import KeycloakPutError, urls_patterns,  KeycloakOpenID
 import json
 from typing import List, Dict
 from keycloak.keycloak_admin import KeycloakAdmin
@@ -14,13 +14,14 @@ from keycloak.exceptions import (
     KeycloakRPTNotFound,
     raise_error_from_response, KeycloakDeleteError,
 )
-
 from jose import jwt
 from .groups_permissions import GroupsPermissions
 
 
 class KeycloakAdminRepository(KeycloakAdmin):
 
+    URL_ADMIN_USER_ROLES = "admin/realms/{realm-name}/users/{id}/role-mappings"
+
     def __init__(
             self,
             server_url,
@@ -240,6 +241,65 @@ class KeycloakAdminRepository(KeycloakAdmin):
         """
         self.realm_name = realm_name
 
+    def _get_roles_of_user(
+        self, role_mapping_url, user_id, **params
+    ):
+        """Get client roles of a single user helper.
+
+        :param client_level_role_mapping_url: Url for the client role mapping
+        :type client_level_role_mapping_url: str
+        :param user_id: User id
+        :type user_id: str
+        :param client_id: Client id
+        :type client_id: str
+        :param params: Additional parameters
+        :type params: dict
+        :returns: Client roles of a user
+        :rtype: list
+        """
+        params_path = {"realm-name": self.realm_name, "id": user_id}
+        data_raw = self.raw_get(
+            role_mapping_url.format(**params_path), **params)
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def get_roles_of_user(self, user_id):
+        """Get all roles for a user.
+
+        :param user_id: id of user
+        :type user_id: str
+        :return: Keycloak server response (array RoleMappingsRepresentation)
+        :rtype: list
+        """
+        return self._get_roles_of_user(
+            self.URL_ADMIN_USER_ROLES, user_id
+        )
+    
+    def get_token_master(self):
+        """Get master admin token.
+        The admin token is then set in the `token` attribute.
+        """
+
+        self.keycloak_openid = KeycloakOpenID(
+            server_url=self.server_url,
+            client_id="admin-cli",
+            realm_name="master",
+            verify=self.verify,
+            client_secret_key=self.client_secret_key,
+            custom_headers=self.custom_headers,
+            timeout=50,
+        )
+
+        grant_type = ["client_credentials",]
+
+        self.token = self.keycloak_openid.token(
+            self.username, self.password, grant_type=grant_type, totp=self.totp
+        )
+        
+        if "access_token" in self.token:
+            return self.token["access_token"]
+
+        return self.token
+
 
 def get_default_keycloak_admin():
     config = settings.KEYCLOAK
@@ -374,6 +434,9 @@ class KeycloakToken:
         except:
             return ''
 
+    def is_superuser(self, token_info):
+        return token_info['realm_name'] == 'master'and token_info['azp'] == "admin-cli"
+
     def get_roles_permissions_user(self, token, public_key_validate='inter', method_token_info="introspect", **kwargs):
         """Get permission by user token.
 
@@ -401,8 +464,11 @@ class KeycloakToken:
 
         if method_token_info == "introspect" and not token_info["active"]:
             raise KeycloakInvalidTokenError("Token expired or invalid.")
-
-        roles = self.get_roles_by_user(token_info['sub'])
+        
+        if self.is_superuser(token_info=token_info):
+            roles = []
+        else:
+            roles = self.get_roles_by_user(token_info['sub'])
 
         find_permissions = [policies['name']
                             for policies in roles if policies['composite']]
